==> ui-components-0.3.9.tgz: package/stories/Post/100c-PostQuote.stories.tsx <==
import {
  EDITOR_TEXT_VALUES,
  getInitialTextString,
} from "../utils/editor-controls";
import { Meta, Story } from "@storybook/react";
import PostQuote, { PostQuoteProps } from "post/PostQuote";

import React from "react";
import { action } from "@storybook/addon-actions";
import crown from "stories/images/crown.png";
import mamoruAvatar from "stories/images/mamoru.png";
import tuxedoAvatar from "stories/images/tuxedo-mask.jpg";

export default {
  title: "Posts / PostQuote",
  component: PostQuote,
} as Meta;

const PostQuoteStoryTemplate: Story<PostQuoteProps> = (args) => {
  return <PostQuote {...args} />;
};
export const Quote = PostQuoteStoryTemplate.bind({});
Quote.args = {
  createdTime: "yesterday",
  createdTimeLink: {
    href: "#test-link",
    onClick: action("clickity-click"),
  },
  text: getInitialTextString(EDITOR_TEXT_VALUES.WITH_IMAGE),
  secretIdentity: {
    name: "Tuxedo Mask",
    avatar: `/${tuxedoAvatar}`,
    accessory: crown,
    color: "#f30cb5",
  },
  userIdentity: { name: "SexyDaddy69", avatar: `/${mamoruAvatar}` },
};
Quote.decorators = [(Story) => <div style={{ width: "300px" }}>{Story()}</div>];

export const LongQuoteWithShrink = PostQuoteStoryTemplate.bind({});
LongQuoteWithShrink.args = {
  ...Quote.args,
  text: getInitialTextString(EDITOR_TEXT_VALUES.LONG_TEXT),
  maxHeightPx: 500,
};
LongQuoteWithShrink.decorators = [
  (Story) => (
    <div
      style={{ width: "300px", backgroundColor: "darkblue", padding: "20px" }}
    >
      {Story()}
    </div>
  ),
];

==> ui-components-0.3.11.tgz: package/stories/Post/100c-PostQuote.stories.tsx <==
import {
  EDITOR_TEXT_VALUES,
  getInitialTextString,
} from "../utils/editor-controls";
import { Meta, Story } from "@storybook/react";
import PostQuote, { PostQuoteProps } from "post/PostQuote";

import React from "react";
import { action } from "@storybook/addon-actions";
import crown from "stories/images/crown.png";
import mamoruAvatar from "stories/images/mamoru.png";
import tuxedoAvatar from "stories/images/tuxedo-mask.jpg";

export default {
  title: "Posts / PostQuote",
  component: PostQuote,
} as Meta;

const PostQuoteStoryTemplate: Story<PostQuoteProps> = (args) => <PostQuote {...args} />;
export const Quote = PostQuoteStoryTemplate.bind({});
Quote.args = {
  createdTime: "yesterday",
  createdTimeLink: {
    href: "#test-link",
    onClick: action("clickity-click"),
  },
  text: getInitialTextString(EDITOR_TEXT_VALUES.WITH_IMAGE),
  secretIdentity: {
    name: "Tuxedo Mask",
    avatar: `/${tuxedoAvatar}`,
    accessory: crown,
    color: "#f30cb5",
  },
  userIdentity: { name: "SexyDaddy69", avatar: `/${mamoruAvatar}` },
};
Quote.decorators = [(Story) => <div style={{ width: "300px" }}>{Story()}</div>];

export const LongQuoteWithShrink = PostQuoteStoryTemplate.bind({});
LongQuoteWithShrink.args = {
  ...Quote.args,
  text: getInitialTextString(EDITOR_TEXT_VALUES.LONG_TEXT),
  maxHeightPx: 500,
};
LongQuoteWithShrink.decorators = [
  (Story) => (
    <div
      style={{ width: "300px", backgroundColor: "darkblue", padding: "20px" }}
    >
      {Story()}
    </div>
  ),
];
